@@ -12,6 +12,9 @@ class SysNotFoundError(Exception):
 class Config:
     def __init__(self):
         self._config_file, self._yaml_conf = Config._read_config()
+        
+        if not self._yaml_conf:
+            self._yaml_conf = {}
 
     @property
     def _anipy_cli_folder(self):
@@ -154,8 +157,8 @@ class Config:
             print(f"Failed to create config file: {repr(e)}")
             sys_exit(1)
     
-    @functools.lru_cache()
     @staticmethod
+    @functools.lru_cache
     def _read_config():
         config_file = Config._get_config_path() / "config.yaml"
         try:
